# Katie

# Copyright 2000-2001 Geoffrey D. Bennett <geoffrey@netcraft.com.au>

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at
# your option) any later version.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA.

package Katie::DB;

use strict;
use Katie::Constants;
use Katie::PGq;

require Exporter;
@Katie::DB::ISA = qw(Exporter);

@Katie::DB::EXPORT = qw(
  $katie_db
  open_vob_db
  new_vob_db
  drop_vob_db
);

use vars qw($katie_db);

$katie_db = undef;

sub open_katie_db {
  return Katie::PGq->new("dbname = katie", DB_CONF_FN);
}

sub init {
  $katie_db = open_katie_db();
}

# return a PGq object for the Katie VOB database with given ID
sub open_vob_db {
  my($vob_id) = @_;

  return Katie::PGq->new("dbname=katie_$vob_id", DB_CONF_FN);
}

# create a new VOB database, and return a PGq object for it
sub new_vob_db {
  my($vob_id) = @_;
  my($katie_db_temp);
  my($new_vob_sql_fn) = PREFIX_DIR . "/share/katie/katie-vob.sql";
  my($new_vob_sql) = scalar(`cat $new_vob_sql_fn`);
  my($vob_db);

  # 'CREATE DATABASE' can't be done inside a transaction, so we do it
  # in a separate database connection.
  $katie_db_temp = open_katie_db();
  $katie_db_temp->exec("
      CREATE DATABASE katie_$vob_id;
  ");

  $vob_db = open_vob_db($vob_id);
  $vob_db->exec($new_vob_sql);

  return $vob_db;
}

# Delete the VOB database (must be done after deleting the entry
# from vob_cache, otherwise the database will still be open)
sub drop_vob_db {
  my($vob_id) = @_;

  $katie_db->exec("
      DROP DATABASE katie_$vob_id;
  ");
}

1;
