# Katie

# Copyright 2000-2001 Geoffrey D. Bennett <geoffrey@netcraft.com.au>

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at
# your option) any later version.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA.

package Katie::PerlRPCServer;

use strict;

use IO::Socket;
use Katie::PerlRPC;

sub new {
  shift(@_);
  my($args) = @_;
  my($self) = {
    fd       => undef,
    conn     => [],
    handlers => $args,
  };

  $self->{socket} = IO::Socket::INET->new(
    Listen    => 5,
    LocalPort => 52843,
    Proto     => 'tcp',
    Reuse     => 1,
  );
  if (!defined($self->{socket})) {
    die "Couldn't listen on port 52843: $!";
  }

  return(bless $self);
}

sub fd {
  my($self) = @_;
  my($fd) = '';

  if ($self->{fd}) {
    return $self->{fd};
  }

  vec($fd, $self->{socket}->fileno(), 1) = 1;
  for my $conn (@{$self->{conn}}) {
    vec($fd, $conn->{socket}->fileno(), 1) = 1;
  }

  return $self->{fd} = $fd;
}

sub handle {
  my($self, $fd) = @_;
  my($conn_num, @deleted);

  # Check for new connections
  if (vec($fd, $self->{socket}->fileno(), 1)) {
    $self->handle_new_conn();
    $self->{fd} = undef;
  }

  # Check for activity on existing connections
  $conn_num = 0;
  for my $conn (@{$self->{conn}}) {
    if (vec($fd, $conn->{socket}->fileno(), 1)) {
      if (!$self->handle_conn($conn)) {
        unshift(@deleted, $conn_num);
      }
    }
    $conn_num++;
  }

  # Remove any connections that were closed
  for $conn_num (@deleted) {
    splice(@{$self->{conn}}, $conn_num, 1);
    $self->{fd} = undef;
  }
}

sub handle_new_conn {
  my($self) = @_;
  my($conn);

  $conn->{socket} = $self->{socket}->accept();
  $conn->{rpc} = new Katie::PerlRPC($conn->{socket});
  bless($conn);
  push(@{$self->{conn}}, $conn);
}

sub handle_conn {
  my($self, $conn) = @_;
  my($msg, $sub);

  $msg = $conn->{rpc}->read();
  if (!defined($msg)) {
    close($conn->{socket});
    return 0;
  }

  if (ref($msg) ne 'ARRAY') {
    warn "received non-array ref\n";
    close($conn->{socket});
    return 0;
  }

  $sub = shift(@$msg);
  if (!exists($self->{handlers}->{$sub})) {
    warn "no handler for $sub\n";
    close($conn->{socket});
    return 0;
  }

  $conn->{rpc}->write([$self->{handlers}->{$sub}->($conn->{rpc}, @$msg)]);

  return 1;
}

1;
