# Katie

# Copyright 2000-2001 Geoffrey D. Bennett <geoffrey@netcraft.com.au>

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at
# your option) any later version.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA.

package Katie::Permissions;

use strict;

require Exporter;
@Katie::Permissions::ISA = qw(Exporter);

@Katie::Permissions::EXPORT = qw(
  ensure_owner
  ensure_group
  ensure_writeable
);

# return true if the user is root or is the given user
sub ensure_owner {
  my($auth, $uid) = @_;

  return ($auth->{uid} == 0 or $auth->{uid} == $uid);
}

# return true if the user is root or in the given group
sub ensure_group {
  my($auth, $gid) = @_;

  return 1 if ($auth->{uid} == 0 or $auth->{gid} == $gid);
  for my $group (@{$auth->{groups}}) {
    return 1 if $group == $gid;
  }

  return 0;
}

# return true if the user can write to the file
sub ensure_writeable {
  my($auth, @attrs) = @_;

  return $attrs[1] & 0200 if (ensure_owner($auth, $attrs[3]));
  return $attrs[1] & 0020 if (ensure_group($auth, $attrs[4]));
  return $attrs[1] & 0002;
}

1;
