# Katie

# Copyright 2000-2001 Geoffrey D. Bennett <geoffrey@netcraft.com.au>

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or (at
# your option) any later version.
# 
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA.

package Katie::Errno;

use strict;

use Katie::NFSerrno;

require Exporter;
@Katie::Errno::ISA = qw(Exporter);
@Katie::Errno::EXPORT = qw(
  kstrerr
  KATIEERR_VOBEXIST
  KATIEERR_VOBNEXIST
  KATIEERR_VIEWEXIST
  KATIEERR_VIEWNEXIST
  KATIEERR_NAMEINVAL
  KATIEERR_CHECKEDOUT
  KATIEERR_CONFSPECNOCO
  KATIEERR_NOTELEM
  KATIEERR_NOTVUPR
  KATIEERR_NOTCHECKEDOUT
  KATIEERR_CHECKINNOTREG
  KATIEERR_MKDIREXISTFILE
  KATIEERR_MKDIRNOCI
  KATIEERR_ELTYPEINVAL
  KATIEERR_LBTYPEEXIST
  KATIEERR_LESSRESTRICT
  KATIEERR_LBTYPENEXIST
  KATIEERR_LABELATTACHED
  KATIEERR_NOTAREV
  KATIEERR_NOREVSELECTED
  KATIEERR_BRTYPEEXIST
  KATIEERR_BRTYPENEXIST
  KATIEERR_BRANCHONELEM
  KATIEERR_BRANCHONBRANCH
  KATIEERR_INVALIDBRPNAME
  KATIEERR_INVALIDMODESTR
);

use constant KATIEERR_VOBEXIST       => 10000;
use constant KATIEERR_VOBNEXIST      => 10001;
use constant KATIEERR_VIEWEXIST      => 10002;
use constant KATIEERR_VIEWNEXIST     => 10003;
use constant KATIEERR_NAMEINVAL      => 10004;
use constant KATIEERR_CHECKEDOUT     => 10005;
use constant KATIEERR_CONFSPECNOCO   => 10006;
use constant KATIEERR_NOTELEM        => 10007;
use constant KATIEERR_NOTVUPR        => 10008;
use constant KATIEERR_NOTCHECKEDOUT  => 10009;
use constant KATIEERR_CHECKINNOTREG  => 10010;
use constant KATIEERR_MKDIREXISTFILE => 10011;
use constant KATIEERR_MKDIRNOCI      => 10012;
use constant KATIEERR_ELTYPEINVAL    => 10013;
use constant KATIEERR_LBTYPEEXIST    => 10014;
use constant KATIEERR_LESSRESTRICT   => 10015;
use constant KATIEERR_LBTYPENEXIST   => 10016;
use constant KATIEERR_LABELATTACHED  => 10017;
use constant KATIEERR_NOTAREV        => 10018;
use constant KATIEERR_NOREVSELECTED  => 10019;
use constant KATIEERR_BRTYPEEXIST    => 10030;
use constant KATIEERR_BRTYPENEXIST   => 10031;
use constant KATIEERR_BRANCHONELEM   => 10032;
use constant KATIEERR_BRANCHONBRANCH => 10033;
use constant KATIEERR_INVALIDBRPNAME => 10034;
use constant KATIEERR_INVALIDMODESTR => 10040;

my(%errors) = (
  10000 => "VOB exists",
  10001 => "VOB does not exist",
  10002 => "View exists",
  10003 => "View does not exist",
  10004 => "Invalid filename",
  10005 => "Is checked out",
  10006 => "Config spec prevents checkout",
  10007 => "Not an element",
  10008 => "Not view-private",
  10009 => "Not checked out",
  10010 => "Check-in file must be a regular file",
  10011 => "Can't create directory over existing file",
  10012 => "Can't create directory and checkin together",
  10013 => "Invalid element type",
  10014 => "Label type exists",
  10015 => "Cannot change to less restrictive label type",
  10016 => "Label type does not exist",
  10017 => "Label is already attached",
  10018 => "Not a revision",
  10019 => "No revision could be selected",
  10030 => "Branch type exists",
  10031 => "Branch type does not exist",
  10032 => "Branch already exists on element",
  10033 => "Branch already exists on branch",
  10034 => "Invalid branch pathname",
  10040 => "Invalid mode string",
);

sub kstrerr {
  my($errno) = @_;

  if ($errors{$errno}) {
    return $errors{$errno};
  }
  return nfsstrerr($errno);
}

1;
